# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetFullRequestStatResultByInstanceIdResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.GetFullRequestStatResultByInstanceIdResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The returned data.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message that contains information such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetFullRequestStatResultByInstanceIdResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetFullRequestStatResultByInstanceIdResponseBodyData(DaraModel):
    def __init__(
        self,
        fail: bool = None,
        is_finish: bool = None,
        result: main_models.GetFullRequestStatResultByInstanceIdResponseBodyDataResult = None,
        result_id: str = None,
        state: str = None,
        timestamp: int = None,
    ):
        # Indicates whether the asynchronous request failed. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.fail = fail
        # Indicates whether the asynchronous request was complete. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.is_finish = is_finish
        # The returned full request data.
        self.result = result
        # The request ID.
        self.result_id = result_id
        # The state of the asynchronous request. Valid values:
        # 
        # *   **RUNNING**
        # *   **SUCCESS**
        # *   **FAIL**
        self.state = state
        # The time when the asynchronous request was sent. The value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.timestamp = timestamp

    def validate(self):
        if self.result:
            self.result.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.fail is not None:
            result['Fail'] = self.fail

        if self.is_finish is not None:
            result['IsFinish'] = self.is_finish

        if self.result is not None:
            result['Result'] = self.result.to_map()

        if self.result_id is not None:
            result['ResultId'] = self.result_id

        if self.state is not None:
            result['State'] = self.state

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Fail') is not None:
            self.fail = m.get('Fail')

        if m.get('IsFinish') is not None:
            self.is_finish = m.get('IsFinish')

        if m.get('Result') is not None:
            temp_model = main_models.GetFullRequestStatResultByInstanceIdResponseBodyDataResult()
            self.result = temp_model.from_map(m.get('Result'))

        if m.get('ResultId') is not None:
            self.result_id = m.get('ResultId')

        if m.get('State') is not None:
            self.state = m.get('State')

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        return self

class GetFullRequestStatResultByInstanceIdResponseBodyDataResult(DaraModel):
    def __init__(
        self,
        list: List[main_models.GetFullRequestStatResultByInstanceIdResponseBodyDataResultList] = None,
        total: int = None,
    ):
        # The full request data.
        self.list = list
        # The total number of entries returned.
        self.total = total

    def validate(self):
        if self.list:
            for v1 in self.list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['List'] = []
        if self.list is not None:
            for k1 in self.list:
                result['List'].append(k1.to_map() if k1 else None)

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.list = []
        if m.get('List') is not None:
            for k1 in m.get('List'):
                temp_model = main_models.GetFullRequestStatResultByInstanceIdResponseBodyDataResultList()
                self.list.append(temp_model.from_map(k1))

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class GetFullRequestStatResultByInstanceIdResponseBodyDataResultList(DaraModel):
    def __init__(
        self,
        avg_examined_rows: float = None,
        avg_fetch_rows: int = None,
        avg_lock_wait_time: float = None,
        avg_logical_read: float = None,
        avg_physical_async_read: int = None,
        avg_physical_sync_read: int = None,
        avg_returned_rows: float = None,
        avg_rt: float = None,
        avg_sql_count: int = None,
        avg_updated_rows: int = None,
        count: int = None,
        count_rate: float = None,
        database: str = None,
        error_count: int = None,
        examined_rows: int = None,
        fetch_rows: int = None,
        ip: str = None,
        lock_wait_time: float = None,
        logical_read: int = None,
        physical_async_read: int = None,
        physical_sync_read: int = None,
        port: int = None,
        psql: str = None,
        rows: int = None,
        rt_greater_than_one_second_count: int = None,
        rt_rate: float = None,
        sql_count: int = None,
        sql_id: str = None,
        sum_updated_rows: int = None,
        tables: List[str] = None,
        version: int = None,
        vpc_id: str = None,
    ):
        # The average number of scanned rows.
        # 
        # > This parameter is returned only for ApsaraDB RDS for MySQL, ApsaraDB RDS for PostgreSQL, and PolarDB for MySQL databases.
        self.avg_examined_rows = avg_examined_rows
        # The average number of rows that are fetched by compute nodes from data nodes on the PolarDB-X 2.0 instance.
        self.avg_fetch_rows = avg_fetch_rows
        # The average lock wait latency. Unit: seconds.
        self.avg_lock_wait_time = avg_lock_wait_time
        # The average number of logical reads.
        self.avg_logical_read = avg_logical_read
        # The average number of physical asynchronous reads.
        self.avg_physical_async_read = avg_physical_async_read
        # The average number of physical synchronous reads.
        self.avg_physical_sync_read = avg_physical_sync_read
        # The average number of returned rows.
        self.avg_returned_rows = avg_returned_rows
        # The average execution duration.
        self.avg_rt = avg_rt
        # The average number of SQL statements.
        self.avg_sql_count = avg_sql_count
        # The average number of updated rows.
        # 
        #  > This parameter is returned only for ApsaraDB RDS for MySQL and PolarDB-X 2.0 databases.
        self.avg_updated_rows = avg_updated_rows
        # The total number of executions.
        self.count = count
        # The percentage of the total number of executions.
        self.count_rate = count_rate
        # The name of the database.
        self.database = database
        # The number of failed executions.
        self.error_count = error_count
        # The total number of scanned rows.
        # 
        # > This parameter is returned only for ApsaraDB RDS for MySQL, ApsaraDB RDS for PostgreSQL, and PolarDB for MySQL databases.
        self.examined_rows = examined_rows
        # The number of rows that are fetched by compute nodes from data nodes on the PolarDB-X 2.0 instance.
        self.fetch_rows = fetch_rows
        # The IP address of the database instance.
        self.ip = ip
        # The lock wait latency. Unit: seconds.
        self.lock_wait_time = lock_wait_time
        # The number of logical reads.
        self.logical_read = logical_read
        # The number of physical asynchronous reads.
        self.physical_async_read = physical_async_read
        # The number of physical synchronous reads.
        self.physical_sync_read = physical_sync_read
        # The port number that is used to connect to the database instance.
        self.port = port
        # The SQL template.
        self.psql = psql
        # The total number of rows updated or returned by the compute nodes of the PolarDB-X 2.0 instance.
        self.rows = rows
        # The number of SQL statements that take longer than 1 second to execute.
        self.rt_greater_than_one_second_count = rt_greater_than_one_second_count
        # The execution duration percentage.
        self.rt_rate = rt_rate
        # The number of SQL statements.
        self.sql_count = sql_count
        # The SQL ID.
        self.sql_id = sql_id
        # The total number of updated rows.
        self.sum_updated_rows = sum_updated_rows
        # The names of tables in the database.
        self.tables = tables
        # The version number.
        self.version = version
        # The virtual private cloud (VPC) ID.
        self.vpc_id = vpc_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.avg_examined_rows is not None:
            result['AvgExaminedRows'] = self.avg_examined_rows

        if self.avg_fetch_rows is not None:
            result['AvgFetchRows'] = self.avg_fetch_rows

        if self.avg_lock_wait_time is not None:
            result['AvgLockWaitTime'] = self.avg_lock_wait_time

        if self.avg_logical_read is not None:
            result['AvgLogicalRead'] = self.avg_logical_read

        if self.avg_physical_async_read is not None:
            result['AvgPhysicalAsyncRead'] = self.avg_physical_async_read

        if self.avg_physical_sync_read is not None:
            result['AvgPhysicalSyncRead'] = self.avg_physical_sync_read

        if self.avg_returned_rows is not None:
            result['AvgReturnedRows'] = self.avg_returned_rows

        if self.avg_rt is not None:
            result['AvgRt'] = self.avg_rt

        if self.avg_sql_count is not None:
            result['AvgSqlCount'] = self.avg_sql_count

        if self.avg_updated_rows is not None:
            result['AvgUpdatedRows'] = self.avg_updated_rows

        if self.count is not None:
            result['Count'] = self.count

        if self.count_rate is not None:
            result['CountRate'] = self.count_rate

        if self.database is not None:
            result['Database'] = self.database

        if self.error_count is not None:
            result['ErrorCount'] = self.error_count

        if self.examined_rows is not None:
            result['ExaminedRows'] = self.examined_rows

        if self.fetch_rows is not None:
            result['FetchRows'] = self.fetch_rows

        if self.ip is not None:
            result['Ip'] = self.ip

        if self.lock_wait_time is not None:
            result['LockWaitTime'] = self.lock_wait_time

        if self.logical_read is not None:
            result['LogicalRead'] = self.logical_read

        if self.physical_async_read is not None:
            result['PhysicalAsyncRead'] = self.physical_async_read

        if self.physical_sync_read is not None:
            result['PhysicalSyncRead'] = self.physical_sync_read

        if self.port is not None:
            result['Port'] = self.port

        if self.psql is not None:
            result['Psql'] = self.psql

        if self.rows is not None:
            result['Rows'] = self.rows

        if self.rt_greater_than_one_second_count is not None:
            result['RtGreaterThanOneSecondCount'] = self.rt_greater_than_one_second_count

        if self.rt_rate is not None:
            result['RtRate'] = self.rt_rate

        if self.sql_count is not None:
            result['SqlCount'] = self.sql_count

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        if self.sum_updated_rows is not None:
            result['SumUpdatedRows'] = self.sum_updated_rows

        if self.tables is not None:
            result['Tables'] = self.tables

        if self.version is not None:
            result['Version'] = self.version

        if self.vpc_id is not None:
            result['VpcId'] = self.vpc_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AvgExaminedRows') is not None:
            self.avg_examined_rows = m.get('AvgExaminedRows')

        if m.get('AvgFetchRows') is not None:
            self.avg_fetch_rows = m.get('AvgFetchRows')

        if m.get('AvgLockWaitTime') is not None:
            self.avg_lock_wait_time = m.get('AvgLockWaitTime')

        if m.get('AvgLogicalRead') is not None:
            self.avg_logical_read = m.get('AvgLogicalRead')

        if m.get('AvgPhysicalAsyncRead') is not None:
            self.avg_physical_async_read = m.get('AvgPhysicalAsyncRead')

        if m.get('AvgPhysicalSyncRead') is not None:
            self.avg_physical_sync_read = m.get('AvgPhysicalSyncRead')

        if m.get('AvgReturnedRows') is not None:
            self.avg_returned_rows = m.get('AvgReturnedRows')

        if m.get('AvgRt') is not None:
            self.avg_rt = m.get('AvgRt')

        if m.get('AvgSqlCount') is not None:
            self.avg_sql_count = m.get('AvgSqlCount')

        if m.get('AvgUpdatedRows') is not None:
            self.avg_updated_rows = m.get('AvgUpdatedRows')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('CountRate') is not None:
            self.count_rate = m.get('CountRate')

        if m.get('Database') is not None:
            self.database = m.get('Database')

        if m.get('ErrorCount') is not None:
            self.error_count = m.get('ErrorCount')

        if m.get('ExaminedRows') is not None:
            self.examined_rows = m.get('ExaminedRows')

        if m.get('FetchRows') is not None:
            self.fetch_rows = m.get('FetchRows')

        if m.get('Ip') is not None:
            self.ip = m.get('Ip')

        if m.get('LockWaitTime') is not None:
            self.lock_wait_time = m.get('LockWaitTime')

        if m.get('LogicalRead') is not None:
            self.logical_read = m.get('LogicalRead')

        if m.get('PhysicalAsyncRead') is not None:
            self.physical_async_read = m.get('PhysicalAsyncRead')

        if m.get('PhysicalSyncRead') is not None:
            self.physical_sync_read = m.get('PhysicalSyncRead')

        if m.get('Port') is not None:
            self.port = m.get('Port')

        if m.get('Psql') is not None:
            self.psql = m.get('Psql')

        if m.get('Rows') is not None:
            self.rows = m.get('Rows')

        if m.get('RtGreaterThanOneSecondCount') is not None:
            self.rt_greater_than_one_second_count = m.get('RtGreaterThanOneSecondCount')

        if m.get('RtRate') is not None:
            self.rt_rate = m.get('RtRate')

        if m.get('SqlCount') is not None:
            self.sql_count = m.get('SqlCount')

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        if m.get('SumUpdatedRows') is not None:
            self.sum_updated_rows = m.get('SumUpdatedRows')

        if m.get('Tables') is not None:
            self.tables = m.get('Tables')

        if m.get('Version') is not None:
            self.version = m.get('Version')

        if m.get('VpcId') is not None:
            self.vpc_id = m.get('VpcId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class SetEventSubscriptionResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.SetEventSubscriptionResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The detailed information.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.SetEventSubscriptionResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class SetEventSubscriptionResponseBodyData(DaraModel):
    def __init__(
        self,
        active: int = None,
        channel_type: str = None,
        contact_group_name: str = None,
        contact_name: str = None,
        event_context: str = None,
        instance_id: str = None,
        lang: str = None,
        level: str = None,
        min_interval: int = None,
        user_id: str = None,
    ):
        # Indicates whether the event subscription feature is enabled. Valid values:
        # 
        # *   **0**: The event subscription feature is disabled.
        # *   **1**: The event subscription feature is enabled.
        self.active = active
        # The notification method. Valid values:
        # 
        # *   **hdm_alarm_sms**: text message.
        # *   **dingtalk**: DingTalk chatbot.
        # *   **hdm_alarm_sms_and_email**: text message and email.
        # *   **hdm_alarm_sms,dingtalk**: text message and DingTalk chatbot.
        self.channel_type = channel_type
        # The name of the contact group that receives alert notifications. Multiple names are separated by commas (,).
        self.contact_group_name = contact_group_name
        # The name of the contact who receives alert notifications. Multiple names are separated by commas (,).
        self.contact_name = contact_name
        # The supported event scenarios. Only **AllContext** is returned for this parameter, which indicates that all scenarios are supported.
        self.event_context = event_context
        # The instance ID.
        self.instance_id = instance_id
        # The language of event notifications. Only **zh-CN** is returned for this parameter, which indicates that event notifications are sent in Chinese.
        self.lang = lang
        # The risk level of the events. Valid values:
        # 
        # *   **Notice**
        # *   **Optimization**
        # *   **Warn**
        # *   **Critical**
        self.level = level
        # The minimum interval between consecutive event notifications. Unit: seconds.
        self.min_interval = min_interval
        # The user ID.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.active is not None:
            result['active'] = self.active

        if self.channel_type is not None:
            result['channelType'] = self.channel_type

        if self.contact_group_name is not None:
            result['contactGroupName'] = self.contact_group_name

        if self.contact_name is not None:
            result['contactName'] = self.contact_name

        if self.event_context is not None:
            result['eventContext'] = self.event_context

        if self.instance_id is not None:
            result['instanceId'] = self.instance_id

        if self.lang is not None:
            result['lang'] = self.lang

        if self.level is not None:
            result['level'] = self.level

        if self.min_interval is not None:
            result['minInterval'] = self.min_interval

        if self.user_id is not None:
            result['userId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('active') is not None:
            self.active = m.get('active')

        if m.get('channelType') is not None:
            self.channel_type = m.get('channelType')

        if m.get('contactGroupName') is not None:
            self.contact_group_name = m.get('contactGroupName')

        if m.get('contactName') is not None:
            self.contact_name = m.get('contactName')

        if m.get('eventContext') is not None:
            self.event_context = m.get('eventContext')

        if m.get('instanceId') is not None:
            self.instance_id = m.get('instanceId')

        if m.get('lang') is not None:
            self.lang = m.get('lang')

        if m.get('level') is not None:
            self.level = m.get('level')

        if m.get('minInterval') is not None:
            self.min_interval = m.get('minInterval')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetAsyncErrorRequestStatByCodeResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.GetAsyncErrorRequestStatByCodeResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetAsyncErrorRequestStatByCodeResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetAsyncErrorRequestStatByCodeResponseBodyData(DaraModel):
    def __init__(
        self,
        complete: bool = None,
        fail: bool = None,
        is_finish: bool = None,
        result: List[main_models.GetAsyncErrorRequestStatByCodeResponseBodyDataResult] = None,
        result_id: str = None,
        state: str = None,
        timestamp: int = None,
    ):
        # Indicates whether the asynchronous request was complete.
        # 
        # *   **true**
        # *   **false**
        self.complete = complete
        # Indicates whether the asynchronous request failed. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.fail = fail
        # Indicates whether the asynchronous request was complete. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.is_finish = is_finish
        # The number of SQL queries corresponding to the error code.
        self.result = result
        # The ID of the asynchronous request.
        self.result_id = result_id
        # The state of the asynchronous request. Valid values:
        # 
        # *   **RUNNING**
        # *   **SUCCESS**
        # *   **FAIL**
        self.state = state
        # The time when the asynchronous request was made. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.timestamp = timestamp

    def validate(self):
        if self.result:
            for v1 in self.result:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.complete is not None:
            result['complete'] = self.complete

        if self.fail is not None:
            result['fail'] = self.fail

        if self.is_finish is not None:
            result['isFinish'] = self.is_finish

        result['result'] = []
        if self.result is not None:
            for k1 in self.result:
                result['result'].append(k1.to_map() if k1 else None)

        if self.result_id is not None:
            result['resultId'] = self.result_id

        if self.state is not None:
            result['state'] = self.state

        if self.timestamp is not None:
            result['timestamp'] = self.timestamp

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('complete') is not None:
            self.complete = m.get('complete')

        if m.get('fail') is not None:
            self.fail = m.get('fail')

        if m.get('isFinish') is not None:
            self.is_finish = m.get('isFinish')

        self.result = []
        if m.get('result') is not None:
            for k1 in m.get('result'):
                temp_model = main_models.GetAsyncErrorRequestStatByCodeResponseBodyDataResult()
                self.result.append(temp_model.from_map(k1))

        if m.get('resultId') is not None:
            self.result_id = m.get('resultId')

        if m.get('state') is not None:
            self.state = m.get('state')

        if m.get('timestamp') is not None:
            self.timestamp = m.get('timestamp')

        return self

class GetAsyncErrorRequestStatByCodeResponseBodyDataResult(DaraModel):
    def __init__(
        self,
        count: int = None,
        error_code: str = None,
        instance_id: str = None,
    ):
        # The number of SQL queries corresponding to the error code.
        self.count = count
        # The error code returned if the request failed.
        self.error_code = error_code
        # The instance ID.
        self.instance_id = instance_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.count is not None:
            result['count'] = self.count

        if self.error_code is not None:
            result['errorCode'] = self.error_code

        if self.instance_id is not None:
            result['instanceId'] = self.instance_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('count') is not None:
            self.count = m.get('count')

        if m.get('errorCode') is not None:
            self.error_code = m.get('errorCode')

        if m.get('instanceId') is not None:
            self.instance_id = m.get('instanceId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetKillInstanceSessionTaskResultResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.GetKillInstanceSessionTaskResultResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, Successful is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetKillInstanceSessionTaskResultResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetKillInstanceSessionTaskResultResponseBodyData(DaraModel):
    def __init__(
        self,
        ignored_user_session_count: int = None,
        instance_id: str = None,
        kill_fail_count: int = None,
        kill_success_count: int = None,
        node_id: str = None,
        result: List[main_models.GetKillInstanceSessionTaskResultResponseBodyDataResult] = None,
        sessions: List[int] = None,
        task_id: str = None,
        task_state: str = None,
        user_id: str = None,
    ):
        # The number of ignored sessions, including sessions of the accounts that are specified by IgnoredUsers, sessions of internal O\\&M accounts of Alibaba Cloud, and **Binlog Dump** sessions.
        self.ignored_user_session_count = ignored_user_session_count
        # The instance ID.
        self.instance_id = instance_id
        # The number of sessions that failed to be terminated.
        self.kill_fail_count = kill_fail_count
        # The number of sessions that were terminated.
        self.kill_success_count = kill_success_count
        # The node ID.
        # 
        # >  This parameter is returned only if the instance is a PolarDB for MySQL cluster.
        self.node_id = node_id
        # The details of the task that terminated sessions.
        self.result = result
        # The session IDs.
        # 
        # >  If all sessions are terminated, the IDs of all sessions on the instance or node are returned.
        self.sessions = sessions
        # The task ID.
        self.task_id = task_id
        # The state of the task that terminates sessions.
        # 
        # *   **RUNNING**: The task is in progress.
        # *   **SUCCESS**: The task is successful.
        # *   **FAILURE**: The task failed.
        # *   **ERROR**: Other errors occur.
        self.task_state = task_state
        # The ID of the Alibaba Cloud account.
        self.user_id = user_id

    def validate(self):
        if self.result:
            for v1 in self.result:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.ignored_user_session_count is not None:
            result['IgnoredUserSessionCount'] = self.ignored_user_session_count

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.kill_fail_count is not None:
            result['KillFailCount'] = self.kill_fail_count

        if self.kill_success_count is not None:
            result['KillSuccessCount'] = self.kill_success_count

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        result['Result'] = []
        if self.result is not None:
            for k1 in self.result:
                result['Result'].append(k1.to_map() if k1 else None)

        if self.sessions is not None:
            result['Sessions'] = self.sessions

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        if self.task_state is not None:
            result['TaskState'] = self.task_state

        if self.user_id is not None:
            result['UserId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('IgnoredUserSessionCount') is not None:
            self.ignored_user_session_count = m.get('IgnoredUserSessionCount')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('KillFailCount') is not None:
            self.kill_fail_count = m.get('KillFailCount')

        if m.get('KillSuccessCount') is not None:
            self.kill_success_count = m.get('KillSuccessCount')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        self.result = []
        if m.get('Result') is not None:
            for k1 in m.get('Result'):
                temp_model = main_models.GetKillInstanceSessionTaskResultResponseBodyDataResult()
                self.result.append(temp_model.from_map(k1))

        if m.get('Sessions') is not None:
            self.sessions = m.get('Sessions')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        if m.get('TaskState') is not None:
            self.task_state = m.get('TaskState')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        return self

class GetKillInstanceSessionTaskResultResponseBodyDataResult(DaraModel):
    def __init__(
        self,
        active: bool = None,
        command: str = None,
        db: str = None,
        host: str = None,
        id: int = None,
        info: str = None,
        reason: str = None,
        state: str = None,
        task_id: str = None,
        time: int = None,
        user: str = None,
    ):
        # Indicates whether the session is active.
        # 
        # > If the type of the command is Query or Execute and the session in the transaction is not terminated, the session is active.
        self.active = active
        # The type of the command executed in the session.
        self.command = command
        # The name of the database.
        self.db = db
        # The IP address and port number of the host that initiated the session.
        self.host = host
        # The session ID.
        self.id = id
        # The SQL statement executed in the session.
        self.info = info
        # The description of the session when the session was terminated.
        # 
        # *   **SESSION_KILLED**: The session is terminated.
        # *   **SESSION_EXPIRED**: The session has expired.
        # *   **SESSION_NO_PERMISSION**: The account used to terminate the session has insufficient permissions.
        # *   **SESSION_ACCOUNT_ERROR**: The account or password used to terminate the session is invalid.
        # *   **SESSION_IGNORED_USER**: The session of the account does not need to be terminated.
        # *   **SESSION_INTERNAL_USER_OR_COMMAND**: The session is a session initiated by or a command run by an Alibaba Cloud O\\&M account.
        # *   **SESSION_KILL_TASK_TIMEOUT**: Timeout occurs when the session is terminated.
        # *   **SESSION_OTHER_ERROR**: Other errors occurred.
        self.reason = reason
        # The status of the session.
        self.state = state
        # The ID of the subtask that terminates the session.
        self.task_id = task_id
        # The execution duration. Unit: seconds.
        self.time = time
        # The account of the database.
        self.user = user

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.active is not None:
            result['Active'] = self.active

        if self.command is not None:
            result['Command'] = self.command

        if self.db is not None:
            result['Db'] = self.db

        if self.host is not None:
            result['Host'] = self.host

        if self.id is not None:
            result['Id'] = self.id

        if self.info is not None:
            result['Info'] = self.info

        if self.reason is not None:
            result['Reason'] = self.reason

        if self.state is not None:
            result['State'] = self.state

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        if self.time is not None:
            result['Time'] = self.time

        if self.user is not None:
            result['User'] = self.user

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Active') is not None:
            self.active = m.get('Active')

        if m.get('Command') is not None:
            self.command = m.get('Command')

        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('Host') is not None:
            self.host = m.get('Host')

        if m.get('Id') is not None:
            self.id = m.get('Id')

        if m.get('Info') is not None:
            self.info = m.get('Info')

        if m.get('Reason') is not None:
            self.reason = m.get('Reason')

        if m.get('State') is not None:
            self.state = m.get('State')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        if m.get('Time') is not None:
            self.time = m.get('Time')

        if m.get('User') is not None:
            self.user = m.get('User')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeCacheAnalysisJobResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeCacheAnalysisJobResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The details of the cache analysis task.
        self.data = data
        # The message that is returned for the request.
        # 
        # >  If the request is successful, **Successful** is returned. If the request fails, an error message that contains information such as an error code is returned.
        self.message = message
        # The ID of the request.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeCacheAnalysisJobResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeCacheAnalysisJobResponseBodyData(DaraModel):
    def __init__(
        self,
        big_keys: main_models.DescribeCacheAnalysisJobResponseBodyDataBigKeys = None,
        big_keys_of_num: main_models.DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNum = None,
        expiry_keys_level_count: main_models.DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCount = None,
        instance_id: str = None,
        job_id: str = None,
        key_prefixes: main_models.DescribeCacheAnalysisJobResponseBodyDataKeyPrefixes = None,
        message: str = None,
        node_id: str = None,
        task_state: str = None,
        unex_big_keys_of_bytes: main_models.DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytes = None,
        unex_big_keys_of_num: main_models.DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNum = None,
    ):
        self.big_keys = big_keys
        self.big_keys_of_num = big_keys_of_num
        self.expiry_keys_level_count = expiry_keys_level_count
        # The instance ID.
        self.instance_id = instance_id
        # The ID of the cache analysis task.
        self.job_id = job_id
        self.key_prefixes = key_prefixes
        # The message that is returned for the request.
        # 
        # >  If the request is successful, **Successful** is returned. If the request fails, an error message that contains information such as an error code is returned.
        self.message = message
        # The ID of the data node on the instance.
        self.node_id = node_id
        # The state of the cache analysis task. Valid values:
        # 
        # *   **BACKUP**: The data is being backed up.
        # *   **ANALYZING**: The data is being analyzed.
        # *   **FINISHED**: The data is analyzed.
        # *   **FAILED**: An error occurred.
        self.task_state = task_state
        self.unex_big_keys_of_bytes = unex_big_keys_of_bytes
        self.unex_big_keys_of_num = unex_big_keys_of_num

    def validate(self):
        if self.big_keys:
            self.big_keys.validate()
        if self.big_keys_of_num:
            self.big_keys_of_num.validate()
        if self.expiry_keys_level_count:
            self.expiry_keys_level_count.validate()
        if self.key_prefixes:
            self.key_prefixes.validate()
        if self.unex_big_keys_of_bytes:
            self.unex_big_keys_of_bytes.validate()
        if self.unex_big_keys_of_num:
            self.unex_big_keys_of_num.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.big_keys is not None:
            result['BigKeys'] = self.big_keys.to_map()

        if self.big_keys_of_num is not None:
            result['BigKeysOfNum'] = self.big_keys_of_num.to_map()

        if self.expiry_keys_level_count is not None:
            result['ExpiryKeysLevelCount'] = self.expiry_keys_level_count.to_map()

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.job_id is not None:
            result['JobId'] = self.job_id

        if self.key_prefixes is not None:
            result['KeyPrefixes'] = self.key_prefixes.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.task_state is not None:
            result['TaskState'] = self.task_state

        if self.unex_big_keys_of_bytes is not None:
            result['UnexBigKeysOfBytes'] = self.unex_big_keys_of_bytes.to_map()

        if self.unex_big_keys_of_num is not None:
            result['UnexBigKeysOfNum'] = self.unex_big_keys_of_num.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('BigKeys') is not None:
            temp_model = main_models.DescribeCacheAnalysisJobResponseBodyDataBigKeys()
            self.big_keys = temp_model.from_map(m.get('BigKeys'))

        if m.get('BigKeysOfNum') is not None:
            temp_model = main_models.DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNum()
            self.big_keys_of_num = temp_model.from_map(m.get('BigKeysOfNum'))

        if m.get('ExpiryKeysLevelCount') is not None:
            temp_model = main_models.DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCount()
            self.expiry_keys_level_count = temp_model.from_map(m.get('ExpiryKeysLevelCount'))

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('JobId') is not None:
            self.job_id = m.get('JobId')

        if m.get('KeyPrefixes') is not None:
            temp_model = main_models.DescribeCacheAnalysisJobResponseBodyDataKeyPrefixes()
            self.key_prefixes = temp_model.from_map(m.get('KeyPrefixes'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('TaskState') is not None:
            self.task_state = m.get('TaskState')

        if m.get('UnexBigKeysOfBytes') is not None:
            temp_model = main_models.DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytes()
            self.unex_big_keys_of_bytes = temp_model.from_map(m.get('UnexBigKeysOfBytes'))

        if m.get('UnexBigKeysOfNum') is not None:
            temp_model = main_models.DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNum()
            self.unex_big_keys_of_num = temp_model.from_map(m.get('UnexBigKeysOfNum'))

        return self

class DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNum(DaraModel):
    def __init__(
        self,
        key_info: List[main_models.DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNumKeyInfo] = None,
    ):
        self.key_info = key_info

    def validate(self):
        if self.key_info:
            for v1 in self.key_info:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['KeyInfo'] = []
        if self.key_info is not None:
            for k1 in self.key_info:
                result['KeyInfo'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.key_info = []
        if m.get('KeyInfo') is not None:
            for k1 in m.get('KeyInfo'):
                temp_model = main_models.DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNumKeyInfo()
                self.key_info.append(temp_model.from_map(k1))

        return self

class DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNumKeyInfo(DaraModel):
    def __init__(
        self,
        bytes: int = None,
        count: int = None,
        db: int = None,
        encoding: str = None,
        expiration_time_millis: int = None,
        key: str = None,
        node_id: str = None,
        type: str = None,
    ):
        self.bytes = bytes
        self.count = count
        self.db = db
        self.encoding = encoding
        self.expiration_time_millis = expiration_time_millis
        self.key = key
        self.node_id = node_id
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.bytes is not None:
            result['Bytes'] = self.bytes

        if self.count is not None:
            result['Count'] = self.count

        if self.db is not None:
            result['Db'] = self.db

        if self.encoding is not None:
            result['Encoding'] = self.encoding

        if self.expiration_time_millis is not None:
            result['ExpirationTimeMillis'] = self.expiration_time_millis

        if self.key is not None:
            result['Key'] = self.key

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.type is not None:
            result['Type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Bytes') is not None:
            self.bytes = m.get('Bytes')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('Encoding') is not None:
            self.encoding = m.get('Encoding')

        if m.get('ExpirationTimeMillis') is not None:
            self.expiration_time_millis = m.get('ExpirationTimeMillis')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        return self

class DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytes(DaraModel):
    def __init__(
        self,
        key_info: List[main_models.DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytesKeyInfo] = None,
    ):
        self.key_info = key_info

    def validate(self):
        if self.key_info:
            for v1 in self.key_info:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['KeyInfo'] = []
        if self.key_info is not None:
            for k1 in self.key_info:
                result['KeyInfo'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.key_info = []
        if m.get('KeyInfo') is not None:
            for k1 in m.get('KeyInfo'):
                temp_model = main_models.DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytesKeyInfo()
                self.key_info.append(temp_model.from_map(k1))

        return self

class DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytesKeyInfo(DaraModel):
    def __init__(
        self,
        bytes: int = None,
        count: int = None,
        db: int = None,
        encoding: str = None,
        expiration_time_millis: int = None,
        key: str = None,
        node_id: str = None,
        type: str = None,
    ):
        self.bytes = bytes
        self.count = count
        self.db = db
        self.encoding = encoding
        self.expiration_time_millis = expiration_time_millis
        self.key = key
        self.node_id = node_id
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.bytes is not None:
            result['Bytes'] = self.bytes

        if self.count is not None:
            result['Count'] = self.count

        if self.db is not None:
            result['Db'] = self.db

        if self.encoding is not None:
            result['Encoding'] = self.encoding

        if self.expiration_time_millis is not None:
            result['ExpirationTimeMillis'] = self.expiration_time_millis

        if self.key is not None:
            result['Key'] = self.key

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.type is not None:
            result['Type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Bytes') is not None:
            self.bytes = m.get('Bytes')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('Encoding') is not None:
            self.encoding = m.get('Encoding')

        if m.get('ExpirationTimeMillis') is not None:
            self.expiration_time_millis = m.get('ExpirationTimeMillis')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        return self

class DescribeCacheAnalysisJobResponseBodyDataKeyPrefixes(DaraModel):
    def __init__(
        self,
        prefix: List[main_models.DescribeCacheAnalysisJobResponseBodyDataKeyPrefixesPrefix] = None,
    ):
        self.prefix = prefix

    def validate(self):
        if self.prefix:
            for v1 in self.prefix:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['Prefix'] = []
        if self.prefix is not None:
            for k1 in self.prefix:
                result['Prefix'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.prefix = []
        if m.get('Prefix') is not None:
            for k1 in m.get('Prefix'):
                temp_model = main_models.DescribeCacheAnalysisJobResponseBodyDataKeyPrefixesPrefix()
                self.prefix.append(temp_model.from_map(k1))

        return self

class DescribeCacheAnalysisJobResponseBodyDataKeyPrefixesPrefix(DaraModel):
    def __init__(
        self,
        bytes: int = None,
        count: int = None,
        key_num: int = None,
        prefix: str = None,
        type: str = None,
    ):
        self.bytes = bytes
        self.count = count
        self.key_num = key_num
        self.prefix = prefix
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.bytes is not None:
            result['Bytes'] = self.bytes

        if self.count is not None:
            result['Count'] = self.count

        if self.key_num is not None:
            result['KeyNum'] = self.key_num

        if self.prefix is not None:
            result['Prefix'] = self.prefix

        if self.type is not None:
            result['Type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Bytes') is not None:
            self.bytes = m.get('Bytes')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('KeyNum') is not None:
            self.key_num = m.get('KeyNum')

        if m.get('Prefix') is not None:
            self.prefix = m.get('Prefix')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        return self

class DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCount(DaraModel):
    def __init__(
        self,
        expiry_level: List[main_models.DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCountExpiryLevel] = None,
    ):
        self.expiry_level = expiry_level

    def validate(self):
        if self.expiry_level:
            for v1 in self.expiry_level:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['ExpiryLevel'] = []
        if self.expiry_level is not None:
            for k1 in self.expiry_level:
                result['ExpiryLevel'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.expiry_level = []
        if m.get('ExpiryLevel') is not None:
            for k1 in m.get('ExpiryLevel'):
                temp_model = main_models.DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCountExpiryLevel()
                self.expiry_level.append(temp_model.from_map(k1))

        return self

class DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCountExpiryLevel(DaraModel):
    def __init__(
        self,
        analysis_ts: int = None,
        level: int = None,
        total_bytes: int = None,
        total_keys: int = None,
    ):
        self.analysis_ts = analysis_ts
        self.level = level
        self.total_bytes = total_bytes
        self.total_keys = total_keys

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.analysis_ts is not None:
            result['AnalysisTs'] = self.analysis_ts

        if self.level is not None:
            result['Level'] = self.level

        if self.total_bytes is not None:
            result['TotalBytes'] = self.total_bytes

        if self.total_keys is not None:
            result['TotalKeys'] = self.total_keys

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AnalysisTs') is not None:
            self.analysis_ts = m.get('AnalysisTs')

        if m.get('Level') is not None:
            self.level = m.get('Level')

        if m.get('TotalBytes') is not None:
            self.total_bytes = m.get('TotalBytes')

        if m.get('TotalKeys') is not None:
            self.total_keys = m.get('TotalKeys')

        return self

class DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNum(DaraModel):
    def __init__(
        self,
        key_info: List[main_models.DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNumKeyInfo] = None,
    ):
        self.key_info = key_info

    def validate(self):
        if self.key_info:
            for v1 in self.key_info:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['KeyInfo'] = []
        if self.key_info is not None:
            for k1 in self.key_info:
                result['KeyInfo'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.key_info = []
        if m.get('KeyInfo') is not None:
            for k1 in m.get('KeyInfo'):
                temp_model = main_models.DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNumKeyInfo()
                self.key_info.append(temp_model.from_map(k1))

        return self

class DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNumKeyInfo(DaraModel):
    def __init__(
        self,
        bytes: int = None,
        count: int = None,
        db: int = None,
        encoding: str = None,
        expiration_time_millis: int = None,
        key: str = None,
        node_id: str = None,
        type: str = None,
    ):
        self.bytes = bytes
        self.count = count
        self.db = db
        self.encoding = encoding
        self.expiration_time_millis = expiration_time_millis
        self.key = key
        self.node_id = node_id
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.bytes is not None:
            result['Bytes'] = self.bytes

        if self.count is not None:
            result['Count'] = self.count

        if self.db is not None:
            result['Db'] = self.db

        if self.encoding is not None:
            result['Encoding'] = self.encoding

        if self.expiration_time_millis is not None:
            result['ExpirationTimeMillis'] = self.expiration_time_millis

        if self.key is not None:
            result['Key'] = self.key

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.type is not None:
            result['Type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Bytes') is not None:
            self.bytes = m.get('Bytes')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('Encoding') is not None:
            self.encoding = m.get('Encoding')

        if m.get('ExpirationTimeMillis') is not None:
            self.expiration_time_millis = m.get('ExpirationTimeMillis')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        return self

class DescribeCacheAnalysisJobResponseBodyDataBigKeys(DaraModel):
    def __init__(
        self,
        key_info: List[main_models.DescribeCacheAnalysisJobResponseBodyDataBigKeysKeyInfo] = None,
    ):
        self.key_info = key_info

    def validate(self):
        if self.key_info:
            for v1 in self.key_info:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['KeyInfo'] = []
        if self.key_info is not None:
            for k1 in self.key_info:
                result['KeyInfo'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.key_info = []
        if m.get('KeyInfo') is not None:
            for k1 in m.get('KeyInfo'):
                temp_model = main_models.DescribeCacheAnalysisJobResponseBodyDataBigKeysKeyInfo()
                self.key_info.append(temp_model.from_map(k1))

        return self

class DescribeCacheAnalysisJobResponseBodyDataBigKeysKeyInfo(DaraModel):
    def __init__(
        self,
        bytes: int = None,
        count: int = None,
        db: int = None,
        encoding: str = None,
        expiration_time_millis: int = None,
        key: str = None,
        node_id: str = None,
        type: str = None,
    ):
        self.bytes = bytes
        self.count = count
        self.db = db
        self.encoding = encoding
        self.expiration_time_millis = expiration_time_millis
        self.key = key
        self.node_id = node_id
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.bytes is not None:
            result['Bytes'] = self.bytes

        if self.count is not None:
            result['Count'] = self.count

        if self.db is not None:
            result['Db'] = self.db

        if self.encoding is not None:
            result['Encoding'] = self.encoding

        if self.expiration_time_millis is not None:
            result['ExpirationTimeMillis'] = self.expiration_time_millis

        if self.key is not None:
            result['Key'] = self.key

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.type is not None:
            result['Type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Bytes') is not None:
            self.bytes = m.get('Bytes')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('Encoding') is not None:
            self.encoding = m.get('Encoding')

        if m.get('ExpirationTimeMillis') is not None:
            self.expiration_time_millis = m.get('ExpirationTimeMillis')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetInstanceMissingIndexListRequest(DaraModel):
    def __init__(
        self,
        avg_total_user_cost: str = None,
        avg_user_impact: str = None,
        end_time: str = None,
        index_count: str = None,
        instance_id: str = None,
        object_name: str = None,
        page_no: str = None,
        page_size: str = None,
        reserved_pages: str = None,
        reserved_size: str = None,
        row_count: str = None,
        start_time: str = None,
        unique_compiles: str = None,
        user_scans: str = None,
        user_seeks: str = None,
    ):
        # The query condition based on the average cost savings.
        self.avg_total_user_cost = avg_total_user_cost
        # The query condition based on the performance improvement.
        self.avg_user_impact = avg_user_impact
        # The end time of the last seek.
        self.end_time = end_time
        # The query condition based on the number of indexes.
        self.index_count = index_count
        # The database instance ID.
        # 
        # >  Only ApsaraDB RDS for SQL Server instances are supported.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The object name.
        self.object_name = object_name
        # The page number. Pages start from page 1. Default value: 1.
        self.page_no = page_no
        # The number of entries per page. Default value: 10.
        self.page_size = page_size
        # The query condition based on the total number of pages.
        self.reserved_pages = reserved_pages
        # The query condition based on the table size.
        self.reserved_size = reserved_size
        # The query condition based on the number of table rows.
        self.row_count = row_count
        # The start time of the last seek.
        self.start_time = start_time
        # The query condition based on the number of compilations.
        self.unique_compiles = unique_compiles
        # The query condition based on the number of scans.
        self.user_scans = user_scans
        # The query condition based on the number of seeks.
        self.user_seeks = user_seeks

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.avg_total_user_cost is not None:
            result['AvgTotalUserCost'] = self.avg_total_user_cost

        if self.avg_user_impact is not None:
            result['AvgUserImpact'] = self.avg_user_impact

        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.index_count is not None:
            result['IndexCount'] = self.index_count

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.object_name is not None:
            result['ObjectName'] = self.object_name

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.reserved_pages is not None:
            result['ReservedPages'] = self.reserved_pages

        if self.reserved_size is not None:
            result['ReservedSize'] = self.reserved_size

        if self.row_count is not None:
            result['RowCount'] = self.row_count

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        if self.unique_compiles is not None:
            result['UniqueCompiles'] = self.unique_compiles

        if self.user_scans is not None:
            result['UserScans'] = self.user_scans

        if self.user_seeks is not None:
            result['UserSeeks'] = self.user_seeks

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AvgTotalUserCost') is not None:
            self.avg_total_user_cost = m.get('AvgTotalUserCost')

        if m.get('AvgUserImpact') is not None:
            self.avg_user_impact = m.get('AvgUserImpact')

        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('IndexCount') is not None:
            self.index_count = m.get('IndexCount')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('ObjectName') is not None:
            self.object_name = m.get('ObjectName')

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('ReservedPages') is not None:
            self.reserved_pages = m.get('ReservedPages')

        if m.get('ReservedSize') is not None:
            self.reserved_size = m.get('ReservedSize')

        if m.get('RowCount') is not None:
            self.row_count = m.get('RowCount')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        if m.get('UniqueCompiles') is not None:
            self.unique_compiles = m.get('UniqueCompiles')

        if m.get('UserScans') is not None:
            self.user_scans = m.get('UserScans')

        if m.get('UserSeeks') is not None:
            self.user_seeks = m.get('UserSeeks')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetDasAgentSSEResponseBody(DaraModel):
    def __init__(
        self,
        answer: str = None,
        event: str = None,
        id: str = None,
        metadata: main_models.GetDasAgentSSEResponseBodyMetadata = None,
    ):
        self.answer = answer
        self.event = event
        self.id = id
        self.metadata = metadata

    def validate(self):
        if self.metadata:
            self.metadata.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.answer is not None:
            result['Answer'] = self.answer

        if self.event is not None:
            result['Event'] = self.event

        if self.id is not None:
            result['Id'] = self.id

        if self.metadata is not None:
            result['Metadata'] = self.metadata.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Answer') is not None:
            self.answer = m.get('Answer')

        if m.get('Event') is not None:
            self.event = m.get('Event')

        if m.get('Id') is not None:
            self.id = m.get('Id')

        if m.get('Metadata') is not None:
            temp_model = main_models.GetDasAgentSSEResponseBodyMetadata()
            self.metadata = temp_model.from_map(m.get('Metadata'))

        return self

class GetDasAgentSSEResponseBodyMetadata(DaraModel):
    def __init__(
        self,
        char_count: int = None,
        code: int = None,
        request_id: str = None,
        tool_name: str = None,
        tool_params: List[str] = None,
    ):
        self.char_count = char_count
        self.code = code
        self.request_id = request_id
        self.tool_name = tool_name
        self.tool_params = tool_params

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.char_count is not None:
            result['CharCount'] = self.char_count

        if self.code is not None:
            result['Code'] = self.code

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.tool_name is not None:
            result['ToolName'] = self.tool_name

        if self.tool_params is not None:
            result['ToolParams'] = self.tool_params

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CharCount') is not None:
            self.char_count = m.get('CharCount')

        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ToolName') is not None:
            self.tool_name = m.get('ToolName')

        if m.get('ToolParams') is not None:
            self.tool_params = m.get('ToolParams')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetAutonomousNotifyEventsInRangeRequest(DaraModel):
    def __init__(
        self,
        end_time: str = None,
        event_context: str = None,
        instance_id: str = None,
        level: str = None,
        min_level: str = None,
        node_id: str = None,
        page_offset: str = None,
        page_size: str = None,
        start_time: str = None,
        context: str = None,
    ):
        # The end of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # >  The end time must be later than the start time.
        # 
        # This parameter is required.
        self.end_time = end_time
        # The reserved parameter.
        self.event_context = event_context
        # The instance ID.
        self.instance_id = instance_id
        # The urgency level of the events. If you specify this parameter, the MinLevel parameter does not take effect. Valid values:
        # 
        # *   **Notice**: events for which the system sends notifications.
        # *   **Optimization**: events that need to be optimized.
        # *   **Warn**: events for which the system sends warnings.
        # *   **Critical**: critical events.
        self.level = level
        # The minimum urgency level of the events. Valid values:
        # 
        # *   **Notice**: events for which the system sends notifications.
        # *   **Optimization**: events that need to be optimized.
        # *   **Warn**: events for which the system sends warnings.
        # *   **Critical**: critical events.
        self.min_level = min_level
        # The ID of the node in a PolarDB for MySQL cluster. You can call the [DescribeDBClusters](https://help.aliyun.com/document_detail/98094.html) operation to query the node ID returned by the DBNodeId response parameter.
        # 
        # >  You must specify the node ID if your database instance is a PolarDB for MySQL cluster.
        self.node_id = node_id
        # The page number. The value must be a positive integer. Default value: 1.
        self.page_offset = page_offset
        # The number of entries per page.
        self.page_size = page_size
        # The beginning of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # This parameter is required.
        self.start_time = start_time
        # The reserved parameter.
        self.context = context

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.event_context is not None:
            result['EventContext'] = self.event_context

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.level is not None:
            result['Level'] = self.level

        if self.min_level is not None:
            result['MinLevel'] = self.min_level

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.page_offset is not None:
            result['PageOffset'] = self.page_offset

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        if self.context is not None:
            result['__context'] = self.context

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('EventContext') is not None:
            self.event_context = m.get('EventContext')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Level') is not None:
            self.level = m.get('Level')

        if m.get('MinLevel') is not None:
            self.min_level = m.get('MinLevel')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('PageOffset') is not None:
            self.page_offset = m.get('PageOffset')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        if m.get('__context') is not None:
            self.context = m.get('__context')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Dict, List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetPfsMetricTrendsResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: Dict[str, List[main_models.DataValue]] = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            for v1 in self.data.values():
                for v2 in v1:
                     if v2:
                        v2.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        result['Data'] = {}
        if self.data is not None:
            for k1, v1 in self.data.items():
                l1 = []
                for k2 in v1:
                    l1.append(k2.to_map() if k2 else None)
                result['Data'][k1] = l1

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        self.data = {}
        if m.get('Data') is not None:
            for k1, v1 in m.get('Data').items():
                l1 = []
                for k2 in v1:
                    temp_model = main_models.DataValue()
                    l1.append(temp_model.from_map(k2))
                self.data[k1] = l1

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetDeadLockDetailListRequest(DaraModel):
    def __init__(
        self,
        db_name_list: str = None,
        end_time: str = None,
        instance_id: str = None,
        page_no: str = None,
        page_size: str = None,
        start_time: str = None,
    ):
        # The name of the database. When you specify multiple databases, you must separate the database names with commas (,).
        self.db_name_list = db_name_list
        # The end of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # This parameter is required.
        self.end_time = end_time
        # The ID of the database instance.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The page number. The value must be an integer that is greater than 0. Default value: 1.
        self.page_no = page_no
        # The number of entries per page. Default value: 10.
        self.page_size = page_size
        # The beginning of the time range to query. Set this parameter to a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        # 
        # This parameter is required.
        self.start_time = start_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.db_name_list is not None:
            result['DbNameList'] = self.db_name_list

        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.page_no is not None:
            result['PageNo'] = self.page_no

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.start_time is not None:
            result['StartTime'] = self.start_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DbNameList') is not None:
            self.db_name_list = m.get('DbNameList')

        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('PageNo') is not None:
            self.page_no = m.get('PageNo')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('StartTime') is not None:
            self.start_time = m.get('StartTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetHDMAliyunResourceSyncResultResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.GetHDMAliyunResourceSyncResultResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
        synchro: str = None,
    ):
        self.code = code
        self.data = data
        self.message = message
        self.request_id = request_id
        self.success = success
        self.synchro = synchro

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        if self.synchro is not None:
            result['Synchro'] = self.synchro

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetHDMAliyunResourceSyncResultResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        if m.get('Synchro') is not None:
            self.synchro = m.get('Synchro')

        return self

class GetHDMAliyunResourceSyncResultResponseBodyData(DaraModel):
    def __init__(
        self,
        error_msg: str = None,
        results: str = None,
        sub_results: main_models.GetHDMAliyunResourceSyncResultResponseBodyDataSubResults = None,
        sync_status: str = None,
    ):
        self.error_msg = error_msg
        self.results = results
        self.sub_results = sub_results
        self.sync_status = sync_status

    def validate(self):
        if self.sub_results:
            self.sub_results.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.error_msg is not None:
            result['ErrorMsg'] = self.error_msg

        if self.results is not None:
            result['Results'] = self.results

        if self.sub_results is not None:
            result['SubResults'] = self.sub_results.to_map()

        if self.sync_status is not None:
            result['SyncStatus'] = self.sync_status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ErrorMsg') is not None:
            self.error_msg = m.get('ErrorMsg')

        if m.get('Results') is not None:
            self.results = m.get('Results')

        if m.get('SubResults') is not None:
            temp_model = main_models.GetHDMAliyunResourceSyncResultResponseBodyDataSubResults()
            self.sub_results = temp_model.from_map(m.get('SubResults'))

        if m.get('SyncStatus') is not None:
            self.sync_status = m.get('SyncStatus')

        return self

class GetHDMAliyunResourceSyncResultResponseBodyDataSubResults(DaraModel):
    def __init__(
        self,
        resource_sync_sub_result: List[main_models.GetHDMAliyunResourceSyncResultResponseBodyDataSubResultsResourceSyncSubResult] = None,
    ):
        self.resource_sync_sub_result = resource_sync_sub_result

    def validate(self):
        if self.resource_sync_sub_result:
            for v1 in self.resource_sync_sub_result:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['ResourceSyncSubResult'] = []
        if self.resource_sync_sub_result is not None:
            for k1 in self.resource_sync_sub_result:
                result['ResourceSyncSubResult'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.resource_sync_sub_result = []
        if m.get('ResourceSyncSubResult') is not None:
            for k1 in m.get('ResourceSyncSubResult'):
                temp_model = main_models.GetHDMAliyunResourceSyncResultResponseBodyDataSubResultsResourceSyncSubResult()
                self.resource_sync_sub_result.append(temp_model.from_map(k1))

        return self

class GetHDMAliyunResourceSyncResultResponseBodyDataSubResultsResourceSyncSubResult(DaraModel):
    def __init__(
        self,
        err_msg: str = None,
        resource_type: str = None,
        success: bool = None,
        sync_count: int = None,
    ):
        self.err_msg = err_msg
        self.resource_type = resource_type
        self.success = success
        self.sync_count = sync_count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.err_msg is not None:
            result['ErrMsg'] = self.err_msg

        if self.resource_type is not None:
            result['ResourceType'] = self.resource_type

        if self.success is not None:
            result['Success'] = self.success

        if self.sync_count is not None:
            result['SyncCount'] = self.sync_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ErrMsg') is not None:
            self.err_msg = m.get('ErrMsg')

        if m.get('ResourceType') is not None:
            self.resource_type = m.get('ResourceType')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        if m.get('SyncCount') is not None:
            self.sync_count = m.get('SyncCount')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DeleteSecurityIPGroupResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DeleteSecurityIPGroupResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        self.code = code
        # ListResult<InstanceSSL>
        self.data = data
        self.message = message
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DeleteSecurityIPGroupResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DeleteSecurityIPGroupResponseBodyData(DaraModel):
    def __init__(
        self,
        global_security_ipgroup: List[main_models.DeleteSecurityIPGroupResponseBodyDataGlobalSecurityIPGroup] = None,
    ):
        self.global_security_ipgroup = global_security_ipgroup

    def validate(self):
        if self.global_security_ipgroup:
            for v1 in self.global_security_ipgroup:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['GlobalSecurityIPGroup'] = []
        if self.global_security_ipgroup is not None:
            for k1 in self.global_security_ipgroup:
                result['GlobalSecurityIPGroup'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.global_security_ipgroup = []
        if m.get('GlobalSecurityIPGroup') is not None:
            for k1 in m.get('GlobalSecurityIPGroup'):
                temp_model = main_models.DeleteSecurityIPGroupResponseBodyDataGlobalSecurityIPGroup()
                self.global_security_ipgroup.append(temp_model.from_map(k1))

        return self

class DeleteSecurityIPGroupResponseBodyDataGlobalSecurityIPGroup(DaraModel):
    def __init__(
        self,
        global_security_group_id: str = None,
    ):
        self.global_security_group_id = global_security_group_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.global_security_group_id is not None:
            result['GlobalSecurityGroupId'] = self.global_security_group_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('GlobalSecurityGroupId') is not None:
            self.global_security_group_id = m.get('GlobalSecurityGroupId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeSqlLogStatisticResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeSqlLogStatisticResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The response code.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   true
        # *   false
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeSqlLogStatisticResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeSqlLogStatisticResponseBodyData(DaraModel):
    def __init__(
        self,
        cold_sql_size: int = None,
        free_cold_sql_size: int = None,
        free_hot_sql_size: int = None,
        hot_sql_size: int = None,
        import_sql_size: int = None,
        timestamp: int = None,
        total_sql_size: int = None,
    ):
        # The size of the SQL Explorer and Audit data that is stored in cold storage. Unit: bytes.
        self.cold_sql_size = cold_sql_size
        # The free quota for cold data storage. Unit: bytes.
        self.free_cold_sql_size = free_cold_sql_size
        # The free quota for hot data storage. Unit: bytes.
        self.free_hot_sql_size = free_hot_sql_size
        # The size of the SQL Explorer and Audit data that is stored in hot storage. Unit: bytes.
        self.hot_sql_size = hot_sql_size
        # The size of the SQL Explorer and Audit data that was generated in the most recent day. Unit: bytes.
        self.import_sql_size = import_sql_size
        # The timestamp. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.timestamp = timestamp
        self.total_sql_size = total_sql_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cold_sql_size is not None:
            result['ColdSqlSize'] = self.cold_sql_size

        if self.free_cold_sql_size is not None:
            result['FreeColdSqlSize'] = self.free_cold_sql_size

        if self.free_hot_sql_size is not None:
            result['FreeHotSqlSize'] = self.free_hot_sql_size

        if self.hot_sql_size is not None:
            result['HotSqlSize'] = self.hot_sql_size

        if self.import_sql_size is not None:
            result['ImportSqlSize'] = self.import_sql_size

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        if self.total_sql_size is not None:
            result['TotalSqlSize'] = self.total_sql_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ColdSqlSize') is not None:
            self.cold_sql_size = m.get('ColdSqlSize')

        if m.get('FreeColdSqlSize') is not None:
            self.free_cold_sql_size = m.get('FreeColdSqlSize')

        if m.get('FreeHotSqlSize') is not None:
            self.free_hot_sql_size = m.get('FreeHotSqlSize')

        if m.get('HotSqlSize') is not None:
            self.hot_sql_size = m.get('HotSqlSize')

        if m.get('ImportSqlSize') is not None:
            self.import_sql_size = m.get('ImportSqlSize')

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        if m.get('TotalSqlSize') is not None:
            self.total_sql_size = m.get('TotalSqlSize')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetYaoChiAgentResponseBody(DaraModel):
    def __init__(
        self,
        content: str = None,
        function_call: List[main_models.GetYaoChiAgentResponseBodyFunctionCall] = None,
        product: str = None,
        query_id: str = None,
        reasoning_content: str = None,
        request_id: str = None,
        session_id: str = None,
        ui_function_call: List[main_models.GetYaoChiAgentResponseBodyUiFunctionCall] = None,
    ):
        self.content = content
        self.function_call = function_call
        self.product = product
        self.query_id = query_id
        self.reasoning_content = reasoning_content
        self.request_id = request_id
        self.session_id = session_id
        self.ui_function_call = ui_function_call

    def validate(self):
        if self.function_call:
            for v1 in self.function_call:
                 if v1:
                    v1.validate()
        if self.ui_function_call:
            for v1 in self.ui_function_call:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.content is not None:
            result['Content'] = self.content

        result['FunctionCall'] = []
        if self.function_call is not None:
            for k1 in self.function_call:
                result['FunctionCall'].append(k1.to_map() if k1 else None)

        if self.product is not None:
            result['Product'] = self.product

        if self.query_id is not None:
            result['QueryId'] = self.query_id

        if self.reasoning_content is not None:
            result['ReasoningContent'] = self.reasoning_content

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.session_id is not None:
            result['SessionId'] = self.session_id

        result['UiFunctionCall'] = []
        if self.ui_function_call is not None:
            for k1 in self.ui_function_call:
                result['UiFunctionCall'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Content') is not None:
            self.content = m.get('Content')

        self.function_call = []
        if m.get('FunctionCall') is not None:
            for k1 in m.get('FunctionCall'):
                temp_model = main_models.GetYaoChiAgentResponseBodyFunctionCall()
                self.function_call.append(temp_model.from_map(k1))

        if m.get('Product') is not None:
            self.product = m.get('Product')

        if m.get('QueryId') is not None:
            self.query_id = m.get('QueryId')

        if m.get('ReasoningContent') is not None:
            self.reasoning_content = m.get('ReasoningContent')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('SessionId') is not None:
            self.session_id = m.get('SessionId')

        self.ui_function_call = []
        if m.get('UiFunctionCall') is not None:
            for k1 in m.get('UiFunctionCall'):
                temp_model = main_models.GetYaoChiAgentResponseBodyUiFunctionCall()
                self.ui_function_call.append(temp_model.from_map(k1))

        return self

class GetYaoChiAgentResponseBodyUiFunctionCall(DaraModel):
    def __init__(
        self,
        args_text: str = None,
        tool_name: str = None,
    ):
        self.args_text = args_text
        self.tool_name = tool_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.args_text is not None:
            result['ArgsText'] = self.args_text

        if self.tool_name is not None:
            result['ToolName'] = self.tool_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ArgsText') is not None:
            self.args_text = m.get('ArgsText')

        if m.get('ToolName') is not None:
            self.tool_name = m.get('ToolName')

        return self

class GetYaoChiAgentResponseBodyFunctionCall(DaraModel):
    def __init__(
        self,
        arguments: str = None,
        id: str = None,
        name: str = None,
        status: str = None,
    ):
        self.arguments = arguments
        self.id = id
        self.name = name
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.arguments is not None:
            result['Arguments'] = self.arguments

        if self.id is not None:
            result['Id'] = self.id

        if self.name is not None:
            result['Name'] = self.name

        if self.status is not None:
            result['Status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Arguments') is not None:
            self.arguments = m.get('Arguments')

        if m.get('Id') is not None:
            self.id = m.get('Id')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        return self

